define(["dojo/_base/declare",
        "dojo/_base/lang",
        "dijit/_Widget",
        "dijit/_TemplatedMixin",
        "dijit/_WidgetsInTemplateMixin",
        "dojo/text!./templates/ImportUserWizardDialog.html",
        "dojo/aspect",
        "dijit/Dialog",
        "dijit/form/Button",
        "admin/users/dialogs/ImportUserWizardController",
        "dojo/request/xhr",
        "dojo/topic",
        "dijit/layout/BorderContainer",
        "dijit/layout/ContentPane",
        "admin/users/dialogs/Wizard",
        "admin/users/dialogs/ImportTypeWizardPage",
        "admin/users/dialogs/LDAPServerInfoWizardPage",
        "admin/users/dialogs/LDAPFiltersWizardPage",
        "admin/users/dialogs/ResultWizardPage"
        
        ],
        function(dDeclare,
                dLang,
                dWidget,
                dTemplatedMixin,
                dWidgetsInTemplateMixin,
                templateText,
                dAspect,
                Dialog,
                Button,
                ImportUserWizardController,
                xhr,
                topic
                ) {
return dDeclare("admin.users.dialogs.ImportUserWizardDialog", [dWidget,dTemplatedMixin,dWidgetsInTemplateMixin], 
{
    /**
     * @private
     */
    baseClass: "ImportUserWizardDialog",

      /**
       * The widget template for the dijit._TemplatedMixin base class.
       */
      templateString: templateText,
      
      /** 
       * Indicate if this widget is also a container
       * @private
       */
      isContainer: false,
      
      /**
       * Indicate if there are widgets in the template
       */
      widgetsInTemplate: true,
      
      /**
       * Ok button label
       */
      okButtonLabel: "OK",
      
      /**
       * Cancel button label
       */
      cancelButtonLabel: "Cancel",
      
      controller: null,
      
      ldapInfo: null,
      
      /**
       * The resize function
       */
      resize: function() {
          this.inherited(arguments);
      },
      
      /**
       * The startup function
       */
      startup: function() {
          this.inherited(arguments);
          this.controller = new ImportUserWizardController();
          this.controller.ldapInfo = this.ldapInfo;
          this.controller.importTypePage = this.page1;
          this.controller.ldapInfoPage = this.page2;
          this.controller.ldapFilterPage = this.page3;
          this.controller.resultPage = this.page4;
          this.dialog.show();
          this.wizard.on("cancel", dLang.hitch(this, '_onCancelClick'));
          this.wizard.on("finish", dLang.hitch(this, '_wizardFinish'));
          this.wizard.mainContainer.resize();
          this.wizard.set("controller", this.controller);
          this.wizard.resetWizard();
      },
      
      /**
       * The postCreate function
       */
      postCreate: function () {
          this.inherited(arguments);
      },
      
      /**
       * The destroy function
       */
      destroy: function() {
    	  this.inherited(arguments);
          //this.dialog.destroyRecursive();
          
      },
      
    onFinish:function () {
    	//supply by caller
    },
      
      /**
       * The OK button handler
       */
    _wizardFinish:function() {
    	if (this.controller.getExternalUserList() == null) {
    		//save ldap info
    		var ldapInfo = this.controller.getLDAPInfo();
			var ldapFilters = this.controller.getLDAPFilters();
			dLang.mixin(ldapInfo, ldapFilters);
			if (this.controller.ldapInfo == null) {
				//add new
				xhr.post("/optim/rest/security/registry/ldap", 
		        {
		        	handleAs: "text",
		        	data: JSON.stringify(ldapInfo),
		        	sync: true
		        }).then(function(data){
		            // Do nothing - no data is returned
		        	console.log(data);
		        }, function(err){
		            //TODO display error message (should be in dita format)
		        	console.log(err);
		        }, function(evt){
		        	//do nothing
		        	console.log(evt);
		        });
			}
			else {
				//update existing
				xhr.put("/optim/rest/security/registry/ldap", 
		        {
		        	handleAs: "text",
		        	data: JSON.stringify(ldapInfo),
		        	sync: true
		        }).then(function(data){
		            // Do nothing - no data is returned
		        	console.log(data);
		        }, function(err){
		            //TODO display error message (should be in dita format)
		        	console.log(err);
		        }, function(evt){
		        	//do nothing
		        	console.log(evt);
		        });
			}
			xhr.post("/optim/rest/security/registry/LDAPSYNCHRONIZE", 
	        {
	        	handleAs: "text",
	        	sync: true
	        }).then(function(data){
	            // Do nothing - no data is returned
	        	console.log(data);
	        }, function(err){
	            //TODO display error message (should be in dita format)
	        	console.log(err);
	        }, function(evt){
	        	//do nothing
	        	console.log(evt);
	        });
			//dispatch event to refresh the user registry
			topic.publish("userRegistry/refresh", null);
    	}
    	else {
    		//delete existing ldap
    		xhr.del("/optim/rest/security/registry/ldap", 
	        {
	        	handleAs: "text",
	        	data: JSON.stringify(ldapInfo),
	        	sync: true
	        }).then(function(data){
	            // Do nothing - no data is returned
	        	console.log(data);
	        }, function(err){
	            //TODO display error message (should be in dita format)
	        	console.log(err);
	        }, function(evt){
	        	//do nothing
	        	console.log(evt);
	        });
    		//this will save the recently retrieved list of users
	        xhr.post("/optim/rest/security/user", 
	        {
	        	handleAs: "text"
	        }).then(function(data){
	            //dispatch event to refresh the user registry
	            topic.publish("userRegistry/refresh", null);
	        }, function(err){
	            //TODO display error message (should be in dita format)
	        }, function(evt){
	        	//do nothing
	        });
    	}
        this.onFinish();
        this.dialog.destroyRecursive();
        this.destroyRecursive();
          
      },
      
      
      /**
       * The cancel button handler
       */
      _onCancelClick:function() {
          this.dialog.destroyRecursive();
          this.destroyRecursive();
      }
});
});
