/* IBM Confidential
* OCO Source Materials
* 5724-U98, 5655-V48, 5724-U50, 5655-V46
* © Copyright IBM Corp. 2013
* The source code for this program is not published or other -
* wise divested of its trade secrets, irrespective of what has
* been deposited with the U.S. Copyright Office.
*/
define(["dojo/_base/declare",
        "dojo/_base/lang",
    	"dojo/store/Memory",
    	"dijit/form/ComboBox",
        "dijit/_Widget",
        "dijit/_TemplatedMixin",
        "dijit/_WidgetsInTemplateMixin",
        "dojo/text!./templates/DsiWizardFirstPage.html",
        "dojo/i18n!./nls/widget_resources"],
        function(dDeclare,					// (dojo/_base/declare)
				 dLang,						// (dojo/_base/lang)
				 dMemory,                   // (dojo/store/Memory)
				 dComboBox,                 // (idx/form/ComboBox)
		         dWidget,					// (dijit/_Widget)
		         dTemplatedMixin,			// (dijit/_TemplatedMixin)
		         dWidgetsInTemplateMixin,	// (dijit/_WidgetsInTemplateMixin)
		         templateText,				// (dojo/text!./templates/DsiWizardFirstPage.html)
		         resources)
{
	//Global Arrays to hold the supported DBMS Vendor and Versions
	var vendorVersions = [];
	
	//Constants
	var DEFAULT_COMBOBOX_TEXT = resources['defaultComboBoxText'];
	
	/**
	 * @name wizard.DsiWizardFirstPage
	 * @class The LoginFrame provides the standard login screen.
	 * @augments dijit._Widget
	 * @augments dijit._TemplatedMixin
	 * 
	 */
return dDeclare("wizard.DsiWizardFirstPage", [dWidget,dTemplatedMixin,dWidgetsInTemplateMixin],
		  /**@lends dsiwidget.wizard.DsiWizardFirstPage#*/		
{
	baseClass: "dsiWizardFirstPage",
	templateString: templateText,

	cannotGoBack: true,
	cannotGoNext: false,
	
	/**
	 * The vendor to preselect
	 */
	vendor: null,
	
	/**
	 * The version to preselect
	 */
	version: null,
	
	vendorLabel: resources['vendorLabel'],
	versionLabel: resources['versionLabel'],
	attributeMap: dLang.delegate(dWidget.prototype.attributeMap, {
		vendorLabel: {node: "vendorLabelNode", type: "innerHTML"},
		versionLabel: {node: "versionLabelNode", type: "innerHTML"}
    }),
	
	
	startup: function(){
		this._getDataStores();
		this.inherited(arguments);
		this.connect(this.vendorComboBox, "onChange", "_handleVendorComboBoxOnChange");
		this.connect(this.versionComboBox, "onChange", "_handleVersionComboBoxOnChange");
		
	},		

	
	getDescription: function() {
		var descriptionMessage = "";
		require(["dojo/dom"], function(dom){
			dom.byId("pageDescrDiv").style.height="5em";
			dom.byId("pageDescrDiv").style.visibility="visible";
    	});
		var fieldsReq = "<table style='border-style:none; margin-top:10px'><tr><td><div class='oneuiMsgInfo16' /></td>"
			fieldsReq += "<td style='padding-left:5px'>" + resources['allFieldsMandatoryMessage'] + "</td></tr></table>";
		if (inBootStrapMode){
			descriptionMessage = "<b>" + resources['wp1OCMDescription'] + "</b><br/>" + fieldsReq;
		}else{
			descriptionMessage = "<b>" + resources['wp1Description'] + "</b><br/>" + fieldsReq;
		}
		this.jarVersionHelp.set("message", resources['jarHoverhelpMessage']);
		return descriptionMessage;
	},
	
	pageInit: function(){		
	//	console.log("pageInit()");
	//Moved inisitialization to pageLoad function	
	},	

	
	pageLoad: function(){
		if ((pageWizardMode == "edit" && !inBootStrapMode)) { // in edit mode
			this._getDataStoreInfo();
			this.vendorComboBox.set("disabled", true); 
		}
		else if ((pageWizardMode == "new" && !inBootStrapMode)  || (bootstrapPayload == null || bootstrapPayload == "")) { // in Create mode
			this.vendorComboBox.set('value', DEFAULT_COMBOBOX_TEXT);
			this.versionComboBox.set('value', DEFAULT_COMBOBOX_TEXT);
			this.vendorComboBox.set("disabled", false); 
			console.log("bootStrap is Null");
		}
		else if (inBootStrapMode) { 
			this._getDataStores();
			this.vendor = bootstrapPayload.vendor;
			this.version = bootstrapPayload.version;
			this.vendorComboBox.set('value', this.vendor);
			this.vendorComboBox.set("disabled", false); 
			this._handleVendorComboBoxOnChange();
			console.log("bootStrap is not null");
		}		
	},
	
	//Get the datastore by id number for an edit operation	
	_getDataStoreInfo: function(){
		var rowData = connectionGrid.getItem(connectionGridSelectedIndex);
		var datastoreIdURL = url + rowData.id;
		console.log("URL: " + datastoreIdURL); 
		var xhrArgs = {
		            url: datastoreIdURL,		          
		            handleAs: 'json',
		            load: dLang.hitch(this, "_handleGetDataStoreInfo"),
					error: dLang.hitch(this, "_handleError")
		    }
		var deferred = dojo.xhrGet(xhrArgs);		
	},
	
	//Handler for datastore info
	//Refactor this
	_handleGetDataStoreInfo: function(data){
		editVendor = data.vendor;
		editVersion = data.version;
		this.editPageLoad(editVendor, editVersion);
	},
	
	editPageLoad: function(editVendor, editVersion){
		 this.vendor = editVendor;
		 this.version = editVersion;
		 this.vendorComboBox.set('value', this.vendor);
		 this._handleVendorComboBoxOnChange();
	},
	
	isReady: function(){		
		return (this.vendorComboBox.value != DEFAULT_COMBOBOX_TEXT && this.versionComboBox.value != DEFAULT_COMBOBOX_TEXT);
	},				

	//HTTP Get - Retrieve all supported DBMS vendors and versions
	
	_getDataStores: function(){
		 var xhrArgs = {
		            url: url + "VENDORVERSIONS",		            
		            handleAs: 'json',
		            sync: true,
		            load: dLang.hitch(this, "_handleVendorVersionData"),
					error: dLang.hitch(this, "_handleError")
		            
		 }
		var deferred = dojo.xhrGet(xhrArgs);		
	},
	
	
	_handleError: function(error){
		var errMsg = "";
		switch(error.status){
			case 404: 
				//Do something special when data store to delete not found??
				errMsg = error.xhr.status+" "+error.xhr.statusText;
				console.log(errMsg);
				break;
			case 500:
				errMsg = error.xhr.status+" "+error.xhr.statusText;
				break;
			default:
				errMsg = error.xhr.status+" "+error.xhr.statusText;
			
		}
		console.log(error.xhr.status+" "+error.xhr.statusText);            				
	},
		
	//Process Supported Vendors and Versions from rest resource
	
	_handleVendorVersionData: function(data){
		console.log(data);	
		vendorVersions = data.vendorVersionMap;
		var vendorArray = [];
		var i = 0;
		//Create array of vendor objects for combo box
		for (var vendor in vendorVersions) {
			vendorArray[i++] = {name: vendor};
		}
		vendorArray.splice(0, 0, {name: DEFAULT_COMBOBOX_TEXT});		
		var vendorStore = new dMemory({data: vendorArray});
		this.vendorComboBox.set('store', vendorStore);		
	},
	

	
	_handleVendorComboBoxOnChange: function() {
		this.versionComboBox.set('value', DEFAULT_COMBOBOX_TEXT);
		var selectedVendor = this.vendorComboBox.get("value");	
		var versionArray = [];
		if(selectedVendor != DEFAULT_COMBOBOX_TEXT){
			var rawVersionArray = vendorVersions[selectedVendor];			
			//Create array of Versions objects for combo box
			if (rawVersionArray != null){
				for (var i = 0; i < rawVersionArray.length; i++) {
					versionArray[i] = {name: rawVersionArray[i]};
				}
				versionArray.splice(0,0,{name: DEFAULT_COMBOBOX_TEXT});
				var versionStore = new dMemory({data: versionArray});
				this.versionComboBox.set('store', versionStore);
				if (this.vendor != null && this.vendor == selectedVendor && this.version != null) {
					this.versionComboBox.set('value', this.version);
				}
			}

		}			
		this._updateWizardButtons();
	},
	
	
	_handleVersionComboBoxOnChange: function() {
			this._updateWizardButtons();
	},
	
	
	_updateWizardButtons: function() {
		var wizard = this.getParent().getParent().getParent(); //->StackContainer->ContentPane(center)->BorderContainer(wizard)
		wizard._checkButtons();
	}
  
});
});
